@@ -7,27 +7,27 @@
 
 #include "SaveHistoryTask.h"
 
-#include <QFileDialog>
 #include <QApplication>
+#include <QFileDialog>
 #include <QTextStream>
 
-#include <KMessageBox>
-#include <KLocalizedString>
-#include <KSharedConfig>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
 
-#include "session/SessionManager.h"
 #include "Emulation.h"
+#include "session/SessionManager.h"
 
-#include "../decoders/PlainTextDecoder.h"
 #include "../decoders/HTMLDecoder.h"
+#include "../decoders/PlainTextDecoder.h"
 
-namespace Konsole {
-
+namespace Konsole
+{
 QString SaveHistoryTask::_saveDialogRecentURL;
 
-SaveHistoryTask::SaveHistoryTask(QObject* parent)
+SaveHistoryTask::SaveHistoryTask(QObject *parent)
     : SessionTask(parent)
 {
 }
@@ -40,13 +40,10 @@ void SaveHistoryTask::execute()
     //        three then providing a URL for each one will be tedious
 
     // TODO - show a warning ( preferably passive ) if saving the history output fails
-    QFileDialog* dialog = new QFileDialog(QApplication::activeWindow());
+    QFileDialog *dialog = new QFileDialog(QApplication::activeWindow());
     dialog->setAcceptMode(QFileDialog::AcceptSave);
 
-    QStringList mimeTypes {
-        QStringLiteral("text/plain"),
-        QStringLiteral("text/html")
-    };
+    QStringList mimeTypes{QStringLiteral("text/plain"), QStringLiteral("text/html")};
     dialog->setMimeTypeFilters(mimeTypes);
 
     KSharedConfigPtr konsoleConfig = KSharedConfig::openConfig();
@@ -80,16 +77,16 @@ void SaveHistoryTask::execute()
 
         if (!url.isValid()) {
             // UI:  Can we make this friendlier?
-            KMessageBox::sorry(nullptr , i18n("%1 is an invalid URL, the output could not be saved.", url.url()));
+            KMessageBox::sorry(nullptr, i18n("%1 is an invalid URL, the output could not be saved.", url.url()));
             continue;
         }
 
         // Save selected URL for next time
-        _saveDialogRecentURL = url.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).toString();
+        _saveDialogRecentURL = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toString();
         group.writePathEntry("Recent URLs", _saveDialogRecentURL);
 
-        KIO::TransferJob* job = KIO::put(url,
-                                         -1,   // no special permissions
+        KIO::TransferJob *job = KIO::put(url,
+                                         -1, // no special permissions
                                          // overwrite existing files
                                          // do not resume an existing transfer
                                          // show progress information only for remote
@@ -100,18 +97,18 @@ void SaveHistoryTask::execute()
                                          // instead, since the overall speed of transfer
                                          // depends on factors other than just the protocol
                                          // used
-                                        );
+        );
 
         SaveJob jobInfo;
         jobInfo.session = session;
-        jobInfo.lastLineFetched = -1;  // when each request for data comes in from the KIO subsystem
+        jobInfo.lastLineFetched = -1; // when each request for data comes in from the KIO subsystem
         // lastLineFetched is used to keep track of how much of the history
         // has already been sent, and where the next request should continue
         // from.
         // this is set to -1 to indicate the job has just been started
 
-        if (((dialog->selectedNameFilter()).contains(QLatin1String("html"), Qt::CaseInsensitive)) ||
-           ((dialog->selectedFiles()).at(0).endsWith(QLatin1String("html"), Qt::CaseInsensitive))) {
+        if (((dialog->selectedNameFilter()).contains(QLatin1String("html"), Qt::CaseInsensitive))
+            || ((dialog->selectedFiles()).at(0).endsWith(QLatin1String("html"), Qt::CaseInsensitive))) {
             Profile::Ptr profile = SessionManager::instance()->sessionProfile(session);
             jobInfo.decoder = new HTMLDecoder(profile->colorScheme(), profile->font());
         } else {
@@ -127,14 +124,14 @@ void SaveHistoryTask::execute()
     dialog->deleteLater();
 }
 
-void SaveHistoryTask::jobDataRequested(KIO::Job* job , QByteArray& data)
+void SaveHistoryTask::jobDataRequested(KIO::Job *job, QByteArray &data)
 {
     // TODO - Report progress information for the job
 
     // PERFORMANCE:  Do some tests and tweak this value to get faster saving
     const int LINES_PER_REQUEST = 500;
 
-    SaveJob& info = _jobSession[job];
+    SaveJob &info = _jobSession[job];
 
     // transfer LINES_PER_REQUEST lines from the session's history
     // to the save location
@@ -148,24 +145,23 @@ void SaveHistoryTask::jobDataRequested(KIO::Job* job , QByteArray& data)
             return; // if there is no more data to transfer then stop the job
         }
 
-        int copyUpToLine = qMin(info.lastLineFetched + LINES_PER_REQUEST ,
-                                sessionLines - 1);
+        int copyUpToLine = qMin(info.lastLineFetched + LINES_PER_REQUEST, sessionLines - 1);
 
         QTextStream stream(&data, QIODevice::ReadWrite);
         info.decoder->begin(&stream);
-        info.session->emulation()->writeToStream(info.decoder , info.lastLineFetched + 1 , copyUpToLine);
+        info.session->emulation()->writeToStream(info.decoder, info.lastLineFetched + 1, copyUpToLine);
         info.decoder->end();
 
         info.lastLineFetched = copyUpToLine;
     }
 }
-void SaveHistoryTask::jobResult(KJob* job)
+void SaveHistoryTask::jobResult(KJob *job)
 {
     if (job->error() != 0) {
-        KMessageBox::sorry(nullptr , i18n("A problem occurred when saving the output.\n%1", job->errorString()));
+        KMessageBox::sorry(nullptr, i18n("A problem occurred when saving the output.\n%1", job->errorString()));
     }
 
-    TerminalCharacterDecoder * decoder = _jobSession[job].decoder;
+    TerminalCharacterDecoder *decoder = _jobSession[job].decoder;
 
     _jobSession.remove(job);
 
