@@ -1,21 +1,8 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
-    Copyright 2009 by Thomas Dreibholz <dreibh@iem.uni-due.de>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2009 Thomas Dreibholz <dreibh@iem.uni-due.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "SearchHistoryTask.h"
@@ -23,23 +10,23 @@
 #include <QApplication>
 #include <QTextStream>
 
+#include "../decoders/PlainTextDecoder.h"
 #include "Emulation.h"
-#include "PlainTextDecoder.h"
 
-namespace Konsole {
-
-void SearchHistoryTask::addScreenWindow(Session* session , ScreenWindow* searchWindow)
+namespace Konsole
+{
+void SearchHistoryTask::addScreenWindow(Session *session, ScreenWindow *searchWindow)
 {
     _windows.insert(session, searchWindow);
 }
 
 void SearchHistoryTask::execute()
 {
-    auto iter = QMapIterator<QPointer<Session>,ScreenWindowPtr>(_windows);
+    auto iter = QMapIterator<QPointer<Session>, ScreenWindowPtr>(_windows);
 
     while (iter.hasNext()) {
         iter.next();
-        executeOnScreenWindow(iter.key() , iter.value());
+        executeOnScreenWindow(iter.key(), iter.value());
     }
 
     if (autoDelete()) {
@@ -47,12 +34,12 @@ void SearchHistoryTask::execute()
     }
 }
 
-void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session , const ScreenWindowPtr& window)
+void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session, const ScreenWindowPtr &window)
 {
     Q_ASSERT(session);
     Q_ASSERT(window);
 
-    Emulation* emulation = session->emulation();
+    Emulation *emulation = session->emulation();
 
     if (!_regExp.pattern().isEmpty()) {
         int pos = -1;
@@ -70,28 +57,28 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
 
         QString string;
 
-        //text stream to read history into string for pattern or regular expression searching
+        // text stream to read history into string for pattern or regular expression searching
         QTextStream searchStream(&string);
 
         PlainTextDecoder decoder;
         decoder.setRecordLinePositions(true);
 
-        //setup first and last lines depending on search direction
+        // setup first and last lines depending on search direction
         int line = startLine;
 
-        //read through and search history in blocks of 10K lines.
-        //this balances the need to retrieve lots of data from the history each time
+        // read through and search history in blocks of 10K lines.
+        // this balances the need to retrieve lots of data from the history each time
         //(for efficient searching)
-        //without using silly amounts of memory if the history is very large.
+        // without using silly amounts of memory if the history is very large.
         const int maxDelta = qMin(window->lineCount(), 10000);
         int delta = forwards ? maxDelta : -maxDelta;
 
         int endLine = line;
-        bool hasWrapped = false;  // set to true when we reach the top/bottom
+        bool hasWrapped = false; // set to true when we reach the top/bottom
         // of the output and continue from the other
         // end
 
-        //loop through history in blocks of <delta> lines.
+        // loop through history in blocks of <delta> lines.
         do {
             // ensure that application does not appear to hang
             // if searching through a lengthy output
@@ -108,9 +95,9 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
                 endLine += delta;
 
                 if (forwards) {
-                    endLine = qMin(startLine , endLine);
+                    endLine = qMin(startLine, endLine);
                 } else {
-                    endLine = qMax(startLine , endLine);
+                    endLine = qMax(startLine, endLine);
                 }
             } else {
                 endLine += delta;
@@ -125,7 +112,7 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
             }
 
             decoder.begin(&searchStream);
-            emulation->writeToStream(&decoder, qMin(endLine, line) , qMax(endLine, line));
+            emulation->writeToStream(&decoder, qMin(endLine, line), qMax(endLine, line));
             decoder.end();
 
             // line number search below assumes that the buffer ends with a new-line
@@ -137,7 +124,7 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
                 pos = string.lastIndexOf(_regExp);
             }
 
-            //if a match is found, position the cursor on that line and update the screen
+            // if a match is found, position the cursor on that line and update the screen
             if (pos != -1) {
                 int newLines = 0;
                 QList<int> linePositions = decoder.linePositions();
@@ -152,12 +139,12 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
 
                 highlightResult(window, findPos);
 
-                emit completed(true);
+                Q_EMIT completed(true);
 
                 return;
             }
 
-            //clear the current block of text and move to the next one
+            // clear the current block of text and move to the next one
             string.clear();
             line = endLine;
         } while (startLine != endLine);
@@ -167,18 +154,17 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
         window->notifyOutputChanged();
     }
 
-    emit completed(false);
+    Q_EMIT completed(false);
 }
-void SearchHistoryTask::highlightResult(const ScreenWindowPtr& window , int findPos)
+void SearchHistoryTask::highlightResult(const ScreenWindowPtr &window, int findPos)
 {
-    //work out how many lines into the current block of text the search result was found
+    // work out how many lines into the current block of text the search result was found
     //- looks a little painful, but it only has to be done once per search.
 
     ////qDebug() << "Found result at line " << findPos;
 
-    //update display to show area of history containing selection
-    if ((findPos < window->currentLine()) ||
-            (findPos >= (window->currentLine() + window->windowLines()))) {
+    // update display to show area of history containing selection
+    if ((findPos < window->currentLine()) || (findPos >= (window->currentLine() + window->windowLines()))) {
         int centeredScrollPos = findPos - window->windowLines() / 2;
         if (centeredScrollPos < 0) {
             centeredScrollPos = 0;
@@ -192,7 +178,7 @@ void SearchHistoryTask::highlightResult(const ScreenWindowPtr& window , int find
     window->setCurrentResultLine(findPos);
 }
 
-SearchHistoryTask::SearchHistoryTask(QObject* parent)
+SearchHistoryTask::SearchHistoryTask(QObject *parent)
     : SessionTask(parent)
     , _direction(Enum::BackwardsSearch)
     , _startLine(0)
